<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compagnon?lang_cible=fa
// ** ne pas modifier le fichier **

return [

	// C
	'compagnon_description' => 'همراه به كاربران در جريان نخستين ازديدشان از قسمت خصوصي اسپيپ كمك ارايه مي‌كند. ',
	'compagnon_nom' => 'همراه ',
	'compagnon_slogan' => 'همراه اول با اسپيپ نيست',
];
